Welcome to the docs!
===============================

.. include:: ../../README.md
   :parser: myst_parser.sphinx_
   :end-before: <!-- start-how-does-ucc-stack-up -->

.. include:: ../../README.md
   :parser: myst_parser.sphinx_
   :start-after: <!-- end-how-does-ucc-stack-up -->

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   Changelog <changelog.rst>
   User Guide <user_guide.rst>
   Contributing Guide <contributing.rst>
   Benchmarking <benchmarking.rst>
   Developer Documentation <dev.rst>
   Code of Conduct <CODE_OF_CONDUCT.rst>
   Research References <research_references.rst>



Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
